

### Jan 14, 2026
* Include ALL fields in "mf jobs get", "mf clusters get", and "mf manifests get" by default
* Smartly format job events and metrics in "mf jobs get"
* Default job list to last 7 days if no time filter is provided
* Add a --watch flag for "mf jobs list" and "mf jobs get" to auto-refresh the output every 10s. 
It should be cancellable with ctl-c. For "mf jobs get" it should show the metrics and events in time order. It should update in place and not scroll the terminal.
* Add "mf rayclusters get" command
* Don't filter out results if there's an exception. Raise an error instead